summaryrefslogtreecommitdiff
path: root/service/service.go
diff options
context:
space:
mode:
Diffstat (limited to 'service/service.go')
-rw-r--r--service/service.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/service/service.go b/service/service.go
index 7ddfbd7a..6ddcda41 100644
--- a/service/service.go
+++ b/service/service.go
@@ -4,9 +4,9 @@ import "sync"
// svc provides high level functionality for road runner svc.
type Service interface {
// Configure must return configure service and return true if service hasStatus enabled. Must return error in case of
// misconfiguration. Services must not be used without proper configuration pushed first.
- Configure(cfg Config, c Container) (enabled bool, err error)
+ Init(cfg Config, c Container) (enabled bool, err error)
// Serve serves.
Serve() error
@@ -4,9 +4,9 @@ import "sync"
// svc provides high level functionality for road runner svc.
type Service interface {
- // Configure must return configure service and return true if service hasStatus enabled. Must return error in case of
+ // Init must return configure service and return true if service hasStatus enabled. Must return error in case of
// misconfiguration. Services must not be used without proper configuration pushed first.